/*-
 *  Copyright (c) 2001  Peter Pentchev
 *  All rights reserved.
 * 
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 
 *  THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 */

#include <errno.h>
#include <stdio.h>
#include <string.h>

#include "vpoppassd.h"
#include "vpp_err.h"

static char	cvs_id[] __unused =
"$Ringlet: vpp_err.c 2629 2008-10-09 09:58:45Z roam $";

static const char *errs[VPP_ERR_LAST] = {
	"no error",
	"out of memory",
	"bad command-line arguments",
	"unknown flavor",
	"no match for the specified flavor",
	"could not find a username in the environment",
	"pipe error",
	"forking child process",
	"program execution error",
	"waiting for child to terminate",
	"reading input",
	"writing output",
	"INTERNAL ERROR"
};

static int errsn[VPP_ERR_LAST] = {
	0, 0, 0,	/* NONE, NOMEM, CMDLINE */
	0, 0,		/* FL_UNKNOWN, FL_NOMATCH */
	0,		/* NOUSER */
	1, 1, 1, 1,	/* PIPE, FORK, EXEC, WAIT */
	1, 1,		/* READ, WRITE */
	0		/* INT */
};

static char	errbuf[512];

/*
 * Function:
 * 	vpp_strerror			- build an error message string
 * Inputs:
 * 	code				- error code
 * Returns:
 * 	pointer to static error message string
 * Modifies:
 * 	errbuf
 */

char *
vpp_strerror(vpp_err_t code) {
	
	if (code > VPP_ERR_INT)
		code = VPP_ERR_INT;

	if (errsn[code])
		snprintf(errbuf, sizeof(errbuf), "%s: %s", errs[code],
		    strerror(errno));
	else
		snprintf(errbuf, sizeof(errbuf), "%s", errs[code]);
	
	return (errbuf);
}

/*
 * Function:
 * 	vpp_prerror			- print error message and context
 * Inputs:
 * 	s				- context string to be printed
 * 	code				- error code
 * Returns:
 * 	code
 * Modifies:
 * 	nothing; writes to stderr
 */

vpp_err_t
vpp_prerror(const char *s, vpp_err_t code) {
	
	if (code > VPP_ERR_INT)
		code = VPP_ERR_INT;
	
	fprintf(stderr, "%s: %s\r\n", s, vpp_strerror(code));
	return (code);
}
