#ifndef _INCLUDED_VPP_FLAVOR_H
#define _INCLUDED_VPP_FLAVOR_H

/*-
 *  Copyright (c) 2001  Peter Pentchev
 *  All rights reserved.
 * 
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 * 
 *  THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 *  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 *  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 *  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 *  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 *  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 *  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 */

/* $Ringlet: vpp_flavor.h 2629 2008-10-09 09:58:45Z roam $ */

/* * *		Definitions		* * */

typedef enum {
	VPP_FL_NONE,
	/* Input */
	VPP_FL_CHECKPWD,
	VPP_FL_VCHKPW,
	/* output */
	VPP_FL_BSDPW,
	VPP_FL_VPASSWD,
	VPP_FL_LAST
} vpp_flavor;

typedef enum {
	VPP_FLT_NONE,
	VPP_FLT_IN,
	VPP_FLT_OUT,
	VPP_FLT_LAST
} vpp_flavor_type;

typedef vpp_err_t	(*vpp_fl_probe)(int, const char *[]);
typedef vpp_err_t	(*vpp_fl_init)(int, const char *[]);
typedef vpp_err_t	(*vpp_fl_change)(const char *);
typedef vpp_err_t	(*vpp_fl_newuser)(const char *);

struct vpp_flavor_hnd {
	vpp_flavor_type	 type;
	const char	*name;
	vpp_flavor	 t;
	vpp_fl_probe	 probe;
	vpp_fl_init	 init;
	vpp_fl_change	 change;
	vpp_fl_newuser	 newuser;
};

/* * *		Variables		* * */


/* * *		Functions		* * */

vpp_err_t	vpp_flavor_set(vpp_flavor_type t, const char *flavor,
		int argc, const char *argv[]);
vpp_err_t	vpp_flavor_probe(vpp_flavor_type t, int argc, const char *argv[]);
vpp_err_t	vpp_flavor_change(const char *pass);
vpp_err_t	vpp_flavor_newuser(const char *pass);

#endif /* _INCLUDED */
